.. SPDX-FileCopyrightText: 2021-2022 Constantine Evans <const@costi.eu>
..
.. SPDX-License-Identifier: AGPL-3.0-only

.. _monitor:

Monitor system
==============

Setup
-----

Configuration
-------------

Command line
------------
